//****************************************************************************
// @Module        Asynchronous / Synchronous Serial Interface (ASC)
// @Filename      ASC.C
// @Project       Teil1.dav
//----------------------------------------------------------------------------
// @Controller    Infineon C164CI-8E
//
// @Compiler      KEIL C166
//
// @Codegenerator DAvE 2-0-0
//
// @Description   This file contains all functions that use the
//                Asynchronous / Synchronous Serial Interface.
//
//----------------------------------------------------------------------------
// @Date          08.04.2013 10:49:17
//
//****************************************************************************


//****************************************************************************
// @Project Includes
//****************************************************************************

#include "MAIN.H"

// USER CODE BEGIN (ASC_General,1)
#include <stdio.h>
// USER CODE END


//***************************************************************************
// @Global Variables
//***************************************************************************

// USER CODE BEGIN (ASC_General,2)
static char globalText[23*4];
static int akt_text_pos;
static int text_length;
// USER CODE END		   


//****************************************************************************
// @Function      void ASC_vInit(void)
//
//----------------------------------------------------------------------------
// @Description   This function initializes the ASC component. It effects all
//                necessary configurations of the SFR, depending on the selected
//                operating mode. The configuration determines whether the ASC
//                interrupts are to be released, and the priority of the 
//                released interrupt.
//
//----------------------------------------------------------------------------
// @Returnvalue   none
//
//----------------------------------------------------------------------------
// @Parameters    none
//
//----------------------------------------------------------------------------
// @Date          08.04.2013 10:49:17
//
//****************************************************************************

void ASC_vInit(void)
{
  ///  8-bit data asynchronous operation
  ///  one stop bit
  ///  divide clock by reload value + constant
  ///  receiver disabled
  S0CON  = 0x0001;

  //   ASC baudrate reload register
  ///  baudrate =  9615,38 Baud
  S0BG   = 0x0040;

  ///  enable transmit interrupt
  ///  transmit interrupt priority level(ILVL) = 1
  ///  transmit interrupt group level (GLVL) = 3
  S0TIC = 0x0047;

  P3    |= 0x0400;    //  set P3.10 output latch (TXD0)
  DP3   |= 0x0400;    /// set P3.10 direction control (TXD0 output)


  // USER CODE BEGIN (ASC_Init,1)

  // USER CODE END

  S0R    = 1;         //  enable baudrate generator
}


//****************************************************************************
// @Function      void ASC_vSendData(uword Data)
//
//----------------------------------------------------------------------------
// @Description   This function writes a send data initialization word into
//                the S0TBUF register.
//                
//                Note:
//                In a multiprocessor system the master with this function
//                has the possibility to send data to the selected slave. To
//                achieve this, the 9th bit must set on zero.
//
//----------------------------------------------------------------------------
// @Returnvalue   none
//
//----------------------------------------------------------------------------
// @Parameters    data to be written into the S0TBUF register
//
//----------------------------------------------------------------------------
// @Date          08.04.2013 10:49:17
//
//****************************************************************************

void ASC_vSendData(uword Data)
{
  S0TBIR = 0;           // reset transmit buffer interrupt request flag
  S0TBUF = Data;        // load transmit buffer register
}


//****************************************************************************
// @Function      void ASC_viIsrTx(void) interrupt S0TINT
//
//----------------------------------------------------------------------------
// @Description   This is the transmit interrupt service routine for the ASC0.
//                It is called when the sending of data is terminated
//                (S0TIR is set).
//                
//                Please note that you have to add application specific
//                code to this function.
//
//----------------------------------------------------------------------------
// @Returnvalue   none
//
//----------------------------------------------------------------------------
// @Parameters    none
//
//----------------------------------------------------------------------------
// @Date          08.04.2013 10:49:17
//
//****************************************************************************

void ASC_viIsrTx(void) interrupt S0TINT
{
  // USER CODE BEGIN (ASC_IsrTx,1)
	if( akt_text_pos != text_length )	// Mehr Text muss bertragen werden
	{
		ASC_vSendData(globalText[akt_text_pos]);
		akt_text_pos++;
	}
  // USER CODE END
}




// USER CODE BEGIN (ASC_General,3)

void test(void)
{
	akt_text_pos = 1;
	text_length = 1;
	ASC_vSendData('A');

}


void DoPrintZ(int iZnr, char *pBuf)
{
	text_length=0;
	while(pBuf)					// Text Lnge
		text_length++;

	sprintf(globalText+(iZnr*23),"%c %c %d %d %s",'\x1B', 'O', 1, iZnr, pBuf);

	ASC_vSendData(globalText[(iZnr-1)*23]);

	akt_text_pos = 1;
}
																							  

void ClrScr( void )
{
//	globalText[0] = 0;
	akt_text_pos = 1;
	text_length = 1;
	ASC_vSendData('\xC');
}
// USER CODE END

