//****************************************************************************
// @Module        General Purpose Timer Unit 1
// @Filename      GT1.C
// @Project       Teil1.dav
//----------------------------------------------------------------------------
// @Controller    Infineon C164CI-8E
//
// @Compiler      KEIL C166
//
// @Codegenerator DAvE 2-0-0
//
// @Description   This file contains all functions that use the GPT1 unit.
//                
//
//----------------------------------------------------------------------------
// @Date          08.04.2013 10:49:17
//
//****************************************************************************


//****************************************************************************
// @Project Includes
//****************************************************************************

#include "MAIN.H"

// USER CODE BEGIN (GT1_General,1)

// USER CODE END


//***************************************************************************
// @Global Variables
//***************************************************************************

// USER CODE BEGIN (GT1_General,2)
static bit 	TASTER_GEDRUECKT = 0;
static char TASTER;
// USER CODE END


//****************************************************************************
// @Function      void GT1_vInit(void)
//
//----------------------------------------------------------------------------
// @Description   This function initializes the GPT1 component. It effects all
//                necessary configurations of the SFR, depending on the selected
//                operating mode. The configuration determines whether the GPT1
//                interrupts are to be released, and the priority of the 
//                released interrupt.
//
//----------------------------------------------------------------------------
// @Returnvalue   none
//
//----------------------------------------------------------------------------
// @Parameters    none
//
//----------------------------------------------------------------------------
// @Date          08.04.2013 10:49:17
//
//****************************************************************************

void GT1_vInit(void)
{
  /// ------------ Timer 3 Control Register ----------
  ///  timer 3 works in timer mode
  ///  prescaler factor is 8
  ///  timer 3 run bit is reset
  ///  up/down control bit is reset 
  ///  external up/down control is disabled
  T3CON = 0x0000;
  T3    = 0x0000;  //  load timer 3 register

  /// ---------- Timer 2 Control Register ----------
  ///  timer 2 works in timer mode
  ///  prescaler factor is 8
  ///  timer 2 run bit is reset
  ///  up/down control bit is reset 
  ///  external up/down control is disabled
  T2CON = 0x0000;
  T2    = 0xFFFF;  //  load timer 2 register

  ///  enable timer 2 interrupt
  ///  timer 2 interrupt priority level(ILVL) = 13
  ///  timer 2 interrupt group level (GLVL) = 3
  T2IC = 0x0077;

  /// ---------- Timer 4 Control Register ----------
  ///  timer 4 works in timer mode
  ///  prescaler factor is 8
  ///  timer 4 run bit is reset
  ///  up/down control bit is reset 
  ///  external up/down control is disabled
  T4CON = 0x0000;
  T4    = 0x0000;  //  load timer 4 register



  // USER CODE BEGIN (GT1_Init,1)

  // USER CODE END


}


//****************************************************************************
// @Function      void GT1_viIsrTmr2(void) interrupt T2INT
//
//----------------------------------------------------------------------------
// @Description   This is the interrupt service routine for the GPT1 timer 2.
//                It is called up when the timer 2 register over or under-
//                flows or if timer 3 is reloaded with the content of timer 2
//                (external signal or T3 over/underflow) or if an external
//                capture event arrives.
//                
//                Please note that you have to add application specific
//                code to this function.
//
//----------------------------------------------------------------------------
// @Returnvalue   none
//
//----------------------------------------------------------------------------
// @Parameters    none
//
//----------------------------------------------------------------------------
// @Date          08.04.2013 10:49:17
//
//****************************************************************************

void GT1_viIsrTmr2(void) interrupt T2INT
{
  // USER CODE BEGIN (GT1_IsrTmr2,1)
  	unsigned char aktP = ((unsigned char) P1H & 0xF0);
  	static unsigned char oldP = 0xF0;
	static int cnt=0;

	if( (aktP  != oldP) && cnt==0 )
	{
	   	if( (aktP&0x10) != (oldP&0x10) )		// PIN4 gedrckt
	   		TASTER = '1';
		else if ( (aktP&0x20) != (oldP&0x20) ) // PIN5 gedrckt
			TASTER = '2';
		else if ( (aktP&0x40) != (oldP&0x40) ) // PIN6 gedrckt
			TASTER = '3';
		else if ( (aktP&0x80) != (oldP&0x80) ) // PIN7 gedrckt
			TASTER = '4';
		else
			TASTER = '0';
	   cnt++;
	}
	else if( (aktP == oldP) && ( cnt == 1 ) )	// Entprellt ber ca. 1 bis 2 Timeroverruns
	{
	 	if(aktP != 0xF0) 
			TASTER_GEDRUECKT = 1;
		cnt = 0;
	}
  	else
	{
		TASTER_GEDRUECKT = 0;
		cnt = 0;
	}

	oldP = aktP;
  // USER CODE END
}




// USER CODE BEGIN (GT1_General,3)
int KeyDown()
{
 bit retw = TASTER_GEDRUECKT;
 if(retw)
 	TASTER_GEDRUECKT = 0;

 return retw;
}

char GetKey()
{
  return TASTER;
}
// USER CODE END

